var findHistogramMax, findHistogramMin, getAxisLabel, humanValueOfStatisticalAbreviation, root;

root = this;

humanValueOfStatisticalAbreviation = {
  mean: "mean",
  std: "standard deviation",
  "var": "variance",
  min: "minimum",
  max: "maximum",
  n: "number of documents"
};

findHistogramMin = function(stats) {
  return Math.max(stats.min, stats.mean - 3 * stats.std);
};

findHistogramMax = function(stats) {
  return Math.min(stats.max, stats.mean + 3 * stats.std);
};

getAxisLabel = function(min, stepSize, numberOfBins) {
  var i;
  return (function() {
    var _i, _results;
    _results = [];
    for (i = _i = 0; 0 <= numberOfBins ? _i < numberOfBins : _i > numberOfBins; i = 0 <= numberOfBins ? ++_i : --_i) {
      _results.push(min + 0.5 * stepSize + i * stepSize);
    }
    return _results;
  })();
};

root.controllers.controller('keyStatCtrl', [
  '$scope', '$routeParams', '$location', 'util', function($scope, $routeParams, $location, util) {
    var base_url, stat_url;
    $scope.name = $routeParams.key;
    $scope.stats = [];
    $scope.queryObject = $routeParams.query || '{}';
    base_url = "/api/" + $routeParams.server + "/" + $routeParams.database + "/" + $routeParams.collection + "/query/" + $scope.queryObject;
    stat_url = "" + base_url + "/stats/" + $routeParams.key;
    $scope.alert = alert;
    $scope.chartConfig = {
      options: {
        chart: {
          type: 'column'
        },
        plotOptions: {
          column: {
            groupPadding: 0,
            pointPadding: 0,
            borderWidth: 0
          }
        }
      },
      xAxis: {
        categories: []
      },
      title: {
        text: 'Distribution'
      },
      loading: false,
      series: [
        {
          data: [],
          name: $routeParams.key,
          color: '#008CBA'
        }
      ]
    };
    $scope.changeQuery = function(query) {
      var r;
      if (query === "") {
        return "";
      }
      r = $routeParams;
      return $location.path("/" + r.server + "/" + r.database + "/" + r.collection + "/stats/" + r.key + "/query/" + query);
    };
    return util.get(stat_url).then(function(res) {
      var histogram_url, key, max, min, numberOfBins, val, _ref;
      _ref = res.data;
      for (key in _ref) {
        val = _ref[key];
        $scope.stats.push({
          name: humanValueOfStatisticalAbreviation[key],
          value: val
        });
      }
      numberOfBins = 50;
      min = findHistogramMin(res.data);
      max = findHistogramMax(res.data);
      histogram_url = "" + base_url + "/histogram/" + $routeParams.key + "/" + min + "/" + max + "/" + numberOfBins;
      return util.get(histogram_url);
    }).then(function(res) {
      $scope.chartConfig.series[0].data = res.data.values;
      return $scope.chartConfig.xAxis.categories = getAxisLabel(res.data.min, res.data.step_size, res.data.values.length);
    });
  }
]);
